@@ -31,6 +31,18 @@ ____other = """
 """
 
 
+class SingletonForEveryClass(type):
+    _instances = {}
+
+    def __call__(cls, *args, **kwargs):
+        tag = f'{cls}'
+        # 其实转字符串来判断是不太严谨的，有些类型字符串后的显示效果是一模一样的
+        # dprint(tag)
+        if tag not in cls._instances:
+            cls._instances[tag] = super(SingletonForEveryClass, cls).__call__(*args, **kwargs)
+        return cls._instances[tag]
+
+
 class SingletonForEveryInitArgs(type):
     """Python单例模式(Singleton)的N种实现 - 知乎: https://zhuanlan.zhihu.com/p/37534850
 
