@@ -145,49 +145,60 @@ class PrettifyStrDecorator:
         return prettifystr(self.last_raw_res)
 
 
-def dict2list(d: dict, *, nsort=False):
-    """字典转n*2的list
-    :param d: 字典
-    :param nsort:
-        True: 对key使用自然排序
-        False: 使用d默认的遍历顺序
-    :return:
-    """
-    ls = list(d.items())
-    if nsort:
-        ls = sorted(ls, key=lambda x: natural_sort_key(str(x[0])))
-    return ls
+class TypeConvert:
+    @classmethod
+    def dict2list(d: dict, *, nsort=False):
+        """ 字典转n*2的list
 
+        :param d: 字典
+        :param nsort:
+            True: 对key使用自然排序
+            False: 使用d默认的遍历顺序
+        :return:
+        """
+        ls = list(d.items())
+        if nsort:
+            ls = sorted(ls, key=lambda x: natural_sort_key(str(x[0])))
+        return ls
 
-def dict2df(d):
-    """dict类型转DataFrame类型"""
-    name = typename(d)
-    if isinstance(d, Counter):
-        li = d.most_common()
-    else:
-        li = dict2list(d, nsort=True)
-    return pd.DataFrame.from_records(li, columns=(f'{name}-key', f'{name}-value'))
+    @classmethod
+    def dict2df(cls, d):
+        """dict类型转DataFrame类型"""
+        name = typename(d)
+        if isinstance(d, Counter):
+            li = d.most_common()
+        else:
+            li = cls.dict2list(d, nsort=True)
+        return pd.DataFrame.from_records(li, columns=(f'{name}-key', f'{name}-value'))
 
+    @classmethod
+    def list2df(cls, li):
+        if li and isinstance(li[0], (list, tuple)):  # 有两维时按表格显示
+            df = pd.DataFrame.from_records(li)
+        else:  # 只有一维时按一列显示
+            df = pd.DataFrame(pd.Series(li), columns=(typename(li),))
+        return df
 
-def list2df(li):
-    if li and isinstance(li[0], (list, tuple)):  # 有两维时按表格显示
-        df = pd.DataFrame.from_records(li)
-    else:  # 只有一维时按一列显示
-        df = pd.DataFrame(pd.Series(li), columns=(typename(li),))
-    return df
+    @classmethod
+    def list2df(cls, li):
+        if li and isinstance(li[0], (list, tuple)):  # 有两维时按表格显示
+            df = pd.DataFrame.from_records(li)
+        else:  # 只有一维时按一列显示
+            df = pd.DataFrame(pd.Series(li), columns=(typename(li),))
+        return df
 
-
-def try2df(arg):
-    """尝试将各种不同的类型转成dataframe"""
-    if isinstance(arg, dict):
-        df = dict2df(arg)
-    elif isinstance(arg, (list, tuple)):
-        df = list2df(arg)
-    elif isinstance(arg, pd.Series):
-        df = pd.DataFrame(arg)
-    else:
-        df = arg
-    return df
+    @classmethod
+    def try2df(cls, arg):
+        """尝试将各种不同的类型转成dataframe"""
+        if isinstance(arg, dict):
+            df = cls.dict2df(arg)
+        elif isinstance(arg, (list, tuple)):
+            df = cls.list2df(arg)
+        elif isinstance(arg, pd.Series):
+            df = pd.DataFrame(arg)
+        else:
+            df = arg
+        return df
 
 
 class NestedDict:
@@ -223,14 +234,14 @@ class NestedDict:
 
         def tohtml(d):
             if max_items:
-                df = try2df(d)
+                df = TypeConvert.try2df(d)
                 if len(df) > max_items:
                     n = len(df)
                     return df[:max_items].to_html(escape=False) + f'... {n - 1}'
                 else:
                     return df.to_html(escape=False)
             else:
-                return try2df(d).to_html(escape=False)
+                return TypeConvert.try2df(d).to_html(escape=False)
 
         if not cls.has_subdict(data):
             res = str(data)
