@@ -32,7 +32,7 @@ try:
     # MatchSimString计算编辑距离需要
     import Levenshtein
 except ModuleNotFoundError:
-    subprocess.run(['pip', 'install', 'python-Levenshtein'])
+    subprocess.run(['pip3', 'install', 'python-Levenshtein'])
     import Levenshtein
 
 # import textract     # ensure_content读取word文档需要
@@ -40,7 +40,7 @@ except ModuleNotFoundError:
 try:  # 拼写检查库，即词汇库
     from spellchecker import SpellChecker
 except ModuleNotFoundError:
-    subprocess.run(['pip', 'install', 'pyspellchecker'])
+    subprocess.run(['pip3', 'install', 'pyspellchecker'])
     from spellchecker import SpellChecker
 
 ____section_1_text = """
@@ -429,6 +429,11 @@ class MatchSimString:
     def __getitem__(self, item):
         return self.origin_str[item]
 
+    def __delitem__(self, item):
+        del self.origin_str[item]
+        del self.key_str[item]
+        del self.ext_value[item]
+
     def __len__(self):
         return len(self.key_str)
 
